@@ -10,13 +10,6 @@ Django_ project.  See the ``docs`` directory for more information.
 
 __author__ = "Joost Cassee"
 __email__ = "joost@cassee.net"
-__version__ = "0.1.0"
+__version__ = "0.2.0"
 __copyright__ = "Copyright (C) 2011 Joost Cassee"
 __license__ = "MIT License"
-
-try:
-    from collections import namedtuple
-except ImportError:
-    namedtuple = lambda name, fields: lambda *values: values
-
-Property = namedtuple('Property', ['num', 'name', 'value'])
